starcluster.spinner.Spinner

Package starcluster :: Module spinner :: Class Spinner |
[hide private]
[frames] | no frames]

# Class Spinner

source code

Instance Methods | [hide private]
__init__(self, type=2) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Print(self, crnt) | source code
curr(self, crnt) Iterator for the character list position | source code
done(self) | source code
stop(self) | source code
run(self) | source code
test(self, sleep=3.4) | source code
Inherited from `threading.Thread`: `__repr__`, `getName`, `isAlive`, `isDaemon`, `is_alive`, `join`, `setDaemon`, `setName`, `start` Inherited from `threading.Thread` (private): `_set_daemon`, `_set_ident` Inherited from `threading._Verbose` (private): `_note` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| spin_screen_pos = `1`
| char_index_pos = `0`
| sleep_time = `1`
| spin_type = `2`

Properties | [hide private]
Inherited from `threading.Thread`: `daemon`, `ident`, `name` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, type=2) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### run(self) | source code
Overrides: threading.Thread.run